#****************************************************************************
#**
#**  File     :  /units/UEOW1104/UEOW1104_script.lua
#**  Author(s):  Drew Staltman, Gordon Duclos, Greg Kohne
#**					Modified By Asdrubaelvect
#**  Summary  :  UEF Spaceships t1 Script
#**
#**  Copyright  2007 Gas Powered Games, Inc.  All rights reserved.
#****************************************************************************

local TAirUnit = import('/lua/terranunits.lua').TAirUnit

local util = import('/lua/utilities.lua')
local fxutil = import('/lua/effectutilities.lua')


local Entity = import('/lua/sim/Entity.lua').Entity
local explosion = import('/lua/defaultexplosions.lua')
local CreateDeathExplosion = explosion.CreateDefaultHitExplosionAtBone
local EffectTemplate = import('/lua/EffectTemplates.lua')
local utilities = import('/lua/Utilities.lua')
local EffectUtil = import('/lua/EffectUtilities.lua')

--Arme Anti Spaceships
local efof_1104_AntiSpaceships_Projectile = import('/mods/OrbitalWarsRebornUEFAlpha/hook/lua/EFOF1104/efof1104weapons.lua').efof_1104_AntiSpaceships_Projectile


UEOW1104 = Class(TAirUnit) {
	DestroyNoFallRandomChance = 1.1,
    Weapons = {
	
		AntiSpaceshipsCiblage = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships01 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships02 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships03 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships04 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships05 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships06 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships07 = Class(efof_1104_AntiSpaceships_Projectile) {},
		AntiSpaceships08 = Class(efof_1104_AntiSpaceships_Projectile) {},
	
	},

	OnStopBeingBuilt = function(self)
		self.AT1 = self:ForkThread(self.ArrivalThread, true)
        TAirUnit.OnStopBeingBuilt(self)
    end,
	
	CreateDamageEffects = function(self, bone, army )
        for k, v in EffectTemplate.DamageFireSmoke01 do
            CreateAttachedEmitter( self, bone, army, v ):ScaleEmitter(1.5)
        end
    end,

    CreateDeathExplosionDustRing = function( self )
        local blanketSides = 18
        local blanketAngle = (2*math.pi) / blanketSides
        local blanketStrength = 1
        local blanketVelocity = 2.8

        for i = 0, (blanketSides-1) do
            local blanketX = math.sin(i*blanketAngle)
            local blanketZ = math.cos(i*blanketAngle)

            local Blanketparts = self:CreateProjectile('/effects/entities/DestructionDust01/DestructionDust01_proj.bp', blanketX, 1.5, blanketZ + 4, blanketX, 0, blanketZ)
                :SetVelocity(blanketVelocity):SetAcceleration(-0.3)
        end        
    end,

	CreateFirePlumes = function( self, army, bones, yBoneOffset )
        local proj, position, offset, velocity
        local basePosition = self:GetPosition()
        for k, vBone in bones do
            position = self:GetPosition(vBone)
            offset = utilities.GetDifferenceVector( position, basePosition )
            velocity = utilities.GetDirectionVector( position, basePosition ) # 
            velocity.x = velocity.x + utilities.GetRandomFloat(-0.3, 0.3)
            velocity.z = velocity.z + utilities.GetRandomFloat(-0.3, 0.3)
            velocity.y = velocity.y + utilities.GetRandomFloat( 0.0, 0.3)
            proj = self:CreateProjectile('/effects/entities/DestructionFirePlume01/DestructionFirePlume01_proj.bp', offset.x, offset.y + yBoneOffset, offset.z, velocity.x, velocity.y, velocity.z)
            proj:SetBallisticAcceleration(utilities.GetRandomFloat(-1, -2)):SetVelocity(utilities.GetRandomFloat(3, 4)):SetCollision(false)
            
            local emitter = CreateEmitterOnEntity(proj, army, '/effects/emitters/destruction_explosion_fire_plume_02_emit.bp')

            local lifetime = utilities.GetRandomFloat( 12, 22 )
        end
    end,
	
	CreateExplosionDebris = function( self, army )
        for k, v in EffectTemplate.ExplosionDebrisLrg01 do
            CreateAttachedEmitter( self, 'UEOW1104', army, v )
        end
    end,
	
	ArrivalThread = function(self)
		WaitSeconds(1.5)
        self:PlayUnitSound('Destroyed')
		WaitSeconds(2.0)
        self:PlayUnitSound('Destroyed')
        local army = self:GetArmy()
		WaitSeconds(3.5)
        # Create Initial explosion effects
        explosion.CreateFlash( self, 'UEOW1104', 4.5, army )
		explosion.CreateFlash( self, 'Arme_Aile_01', 4.5, army )
		explosion.CreateFlash( self, 'Arme_Aile_02', 4.5, army )
		explosion.CreateFlash( self, 'Object19', 4.5, army )
		explosion.CreateFlash( self, 'UEB1105', 4.5, army )
		WaitSeconds(2.5)
		self:PlayUnitSound('Destroyed')

        WaitSeconds(1)
        
        CreateDeathExplosion( self, 'UEOW1104', 1.5)

        WaitSeconds( 1 )
        self:CreateDeathExplosionDustRing()
		self:PlayUnitSound('Destroyed')
        WaitSeconds(0.4)
		
	#############COMMANDER	
		local totalBones = self:GetBoneCount() - 1
        local army = self:GetArmy()
        for k, v in EffectTemplate.SmokeLrg01 do
            for bone = 1, totalBones do
                CreateAttachedEmitter(self,bone,army, v)
            end
        end
		WaitSeconds(1)
		explosion.CreateFlash( self, 'UEOW1104', 4.5, army )
		explosion.CreateFlash( self, 'Arme_Aile_02', 2.5, army )
		explosion.CreateFlash( self, 'Arme_Aile_01', 2.5, army )
		WaitSeconds(1)
		for k, v in EffectTemplate.SmokeLrg01 do
            for bone = 1, totalBones do
                CreateAttachedEmitter(self,bone,army, v)
            end
        end
		WaitSeconds(1.8)
		for k, v in EffectTemplate.SmokeLrg01 do
            for bone = 1, totalBones do
                CreateAttachedEmitter(self,bone,army, v)
            end
        end
		WaitSeconds(3.6)
		for k, v in EffectTemplate.SmokeLrg01 do
            for bone = 1, totalBones do
                CreateAttachedEmitter(self,bone,army, v)
            end
        end
	#############COMMANDER
        WaitSeconds(0.5)
        CreateDeathExplosion( self, 'UEOW1104', 2)
    end,
	
}
TypeClass = UEOW1104