#****************************************************************************
#**
#**  File     :  units/UELc0309/UELc0309_script.lua
#**
#**  Summary  :  UELc0309
#**
#**  Copyright  2005 Gas Powered Games, Inc.  All rights reserved.
#****************************************************************************

local explosion = import('/lua/defaultexplosions.lua')
local util = import('/lua/utilities.lua')

local TAirUnit = import('/lua/terranunits.lua').TAirUnit

local EffectTemplate = import('/lua/EffectTemplates.lua')

UELc0309 = Class(TAirUnit) {
	DestroyNoFallRandomChance = 0,
	
	AirDestructionEffectBones = { 'Exhaust_01','Exhaust_02','Exhaust_03','Exhaust_04'},

    BeamExhaustCruise = '/effects/emitters/transport_thruster_beam_01_emit.bp',
    BeamExhaustIdle = '/effects/emitters/transport_thruster_beam_02_emit.bp',

    DestructionTicks = 250,
    EngineRotateBones = {'Jet_02', 'Jet_01', },

    PlayDestructionEffects = true,
    DamageEffectPullback = 0.25,
    DestroySeconds = 1.5,
	
	OnCreate = function(self)
        TAirUnit.OnCreate(self)

    end,

    OnStopBeingBuilt = function(self,builder,layer)
        TAirUnit.OnStopBeingBuilt(self,builder,layer)
        self.EngineManipulators = {}

        # create the engine thrust manipulators
        for k, v in self.EngineRotateBones do
            table.insert(self.EngineManipulators, CreateThrustController(self, "thruster", v))
        end

        # set up the thursting arcs for the engines
        for keys,values in self.EngineManipulators do
            #                      XMAX,XMIN,YMAX,YMIN,ZMAX,ZMIN, TURNMULT, TURNSPEED
            values:SetThrustingParam( -0.0, 0.0, -0, 0, -50, 0, 1.0,      0.25 )
        end
        if(self:GetCurrentLayer() == 'Land') then
            self.AT1 = self:ForkThread(self.TransformThread, true)
        end
    end,

    OnMotionHorzEventChange = function(self, new, old)
        TAirUnit.OnMotionHorzEventChange(self, new, old)
        if self:IsDead() then return end
        if( not self.IsWaiting ) then
        end
    end,

    OnLayerChange = function(self, new, old)
        TAirUnit.OnLayerChange(self, new, old)
        if( old != 'None' ) then
            if( self.AT1 ) then
                self.AT1:Destroy()
                self.AT1 = nil
            end
            local myBlueprint = self:GetBlueprint()
            if( new == 'Land' ) then
				
                self.AT1 = self:ForkThread(self.TransformThread, true)
            elseif( new == 'Air' ) then
                self.AT1 = self:ForkThread(self.TransformThread, false)
            end
        end
    end,


    TransformThread = function(self, land)
        if( not self.OpenAnimManip ) then
            self.OpenAnimManip = CreateAnimator(self)
        end
        local bp = self:GetBlueprint()
		local army = self:GetArmy()
        if( land ) then
			self:SetImmobile(true)
			self:PlayUnitSound('Landing')
				for k, v in EffectTemplate.TIFCruiseMissileLaunchSmoke do
				CreateAttachedEmitter( self, 'Effet_Sol_01', army, v ):ScaleEmitter(1.2)
				CreateAttachedEmitter( self, 'Effet_Sol_02', army, v ):ScaleEmitter(1.2)
				CreateAttachedEmitter( self, 'Effet_Sol_03', army, v ):ScaleEmitter(1.2)
				CreateAttachedEmitter( self, 'Effet_Sol_04', army, v ):ScaleEmitter(1.2)
				CreateAttachedEmitter( self, 'uelc_0201', army, v ):ScaleEmitter(2.0)
				end
			self:PlayUnitSound('Thruster')
			self.OpenAnimManip = CreateAnimator(self)
			self.OpenAnimManip:PlayAnim(self:GetBlueprint().Display.AnimationOpen, false):SetRate(0.5)
			WaitSeconds(0.3)
			local bp = self:GetBlueprint()
			local buildUnit = bp.Economy.BuildUnit   
			local pos = self:GetPosition()
			local aiBrain = self:GetAIBrain()
			
				for k, v in EffectTemplate.UnitTeleportSteam01 do
				CreateAttachedEmitter( self, 'uelc_0201', army, v ):ScaleEmitter(2.0)
				end
			WaitSeconds(0.1)
				for k, v in EffectTemplate.UnitTeleportSteam01 do
				CreateAttachedEmitter( self, 'uelc_0201', army, v ):ScaleEmitter(2.0)
				end
			
			CreateUnitHPR(
				buildUnit,
				aiBrain.Name,
				pos[1], pos[2], pos[3],
				0, 0, 0
			)			
          WaitFor(self.OpenAnimManip)	   
		  WaitSeconds(2)
			self:Destroy()
            self.IsWaiting = false
            self.Trash:Add(self.OpenAnimManip)
        else
            self.IsWaiting = true
            self.OpenAnimManip:Destroy()
            self.OpenAnimManip = nil
        end
    end,

    EggConstruction = State {
        Main = function(self)
            local bp = self:GetBlueprint()
            local buildUnit = bp.Economy.BuildUnit
            self:GetAIBrain():BuildUnit( self, buildUnit, 1 )
        end,
    },
    
    OnStopBuild = function(self, unitBeingBuilt, order)
        if unitBeingBuilt:GetFractionComplete() == 1 then
            ForkThread(function()
                WaitSeconds(0.3)
                self:Destroy()
            end)
        end
    end,

}

TypeClass = UELc0309